@@ -719,8 +719,6 @@ def get_data(file_path, **kwargs):
                 file_data['created_time'] = get_create_time(file_path)
             if 'size' in data_include:
                 file_data['size'] = os.path.getsize(file_path)
-
-
             return file_data
         except FileNotFoundError as error:
             logger.warning("Error: %s", error)
@@ -1108,6 +1106,7 @@ def get_files(search_path=False, **kwargs):
 
     threaded = obj.get_kwarg(['threaded', 'thread'], True, bool, **kwargs)
     recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
+    include_meta_data = obj.get_kwarg(['image meta data', 'meta data'], False, bool, **kwargs)
 
     data_include = obj.get_kwarg(['data include'], [], (list, str), **kwargs)
     if isinstance(data_include, (str)):
@@ -1177,7 +1176,9 @@ def get_files(search_path=False, **kwargs):
 
         # path_files = index_files(path, extension_array, ignore_array, recursive)
         # file_array = path_files + file_array
-    file_array = _add_jpg_meta_data(file_array)
+    if include_meta_data is True:
+        file_array = _add_jpg_meta_data(file_array)
+    
     return file_array
 
 def _add_jpg_meta_data(file_array):
