@@ -164,7 +164,8 @@ def to_webp(src_path,**kwargs):
         if f.exists(output_path):
             outputs.append(output_path)
             if delete_original_after is True:
-                f.delete(path)
+                if output_path != path:
+                    f.delete(path)
             
             
     return outputs
@@ -209,7 +210,8 @@ def to_jpg(src_path,**kwargs):
         if f.exists(output_path):
             outputs.append(output_path)
             if delete_original_after is True:
-                f.delete(path)
+                if output_path != path:
+                    f.delete(path)
 
     return outputs
 
@@ -322,13 +324,16 @@ def _convert_image(src_path,output_ext):
         return False
     else:
         output_path = f"{os.path.dirname(src_path)}/{f.get_name_no_ext(src_path)}.{extension}"
-        # print(f"output_path: {output_path}")
+        print(f"output_path: {output_path}")
         try:
             im = Image.open(src_path)
+            convert_to = 'RGB'
             if has_transparency(im) is True:
-                im = im.convert("RGBA")
-            else:
-                im = im.convert("RGB")
+                convert_to = "RGBA"
+            if extension == "jpg":
+                extension ="jpeg"
+                convert_to = "RGB"
+            im = im.convert(convert_to)
             im.save(output_path,extension)
             return output_path
         except UnidentifiedImageError:
