@@ -264,6 +264,7 @@ def set_keywords(files,keywords='',**kwargs):
     keywords = _keywords_to_list(keywords,",",snake_case=snake_case)
     # exif_tool_array = []
     for file in file_array:
+        print(f"updating file's keywords: {file['file_path']}")
         if 'meta_data' not in file:
             file = get_meta(file)  
         file['meta_data']['XMP:Subject'] = keywords
@@ -450,11 +451,15 @@ def replace_keyword(files,needle,replace):
         kws = get_keywords(file)
         for ndl in needle:
             if ndl in kws:
-                kws.remove(ndl)
-                kws.append(replace)
-                set_keywords(file,kws)
+                print(f"replacing {ndl} with {replace}")
+                # kws.remove(ndl)
+                # kws.append(replace)
+                file = delete_keyword(file,ndl,save=False)[0]
+                file = add_keyword(file,replace,save=False)[0]
+                # file = set_keywords(file,kws,save=False)[0]
                 update_array.append(file)
     if len(update_array) > 0:
+        print(f"saving {len(update_array)} files.")
         save_file_obj(update_array)
         
     return file_array
@@ -579,14 +584,14 @@ def apply_keyword_synonyms(files,synonyms,**kwargs):
 def auto_tag_by_folder_name(watch_path,**kwargs):
     print(f"auto_tag_by_folder_name")
     synonyms = obj.get_kwarg(['synonyms'],False,(bool,dict),**kwargs)
-    all_files = f.get_files(watch_path, ext="images")
+    all_files = f.get_files(watch_path, ext="images",data_include="img_meta_data")
     print(f"watching {len(all_files)} files")
     # duration = 0
 
     while True:
         time.sleep(.5)
         if len(all_files) == 0:
-            all_files = f.get_files(watch_path, ext="images")
+            all_files = f.get_files(watch_path, ext="images",data_include="img_meta_data")
         # duration += .5
         # if duration % 10 == 0:
         #     transferCompleteImages.transferCompleteImages()
